@@ -56,10 +56,6 @@ def calculate(array, pixel, masks = None, method = 'sum', convert = None,
 
     method_options = ['sum','mean']
     unit_options = ['TAF','SI']
-    convert_options = ['depth','snow_depth','volume', None]
-
-    if convert not in convert_options:
-        raise Exception('convert options are {}'.format(convert_options))
 
     if method not in method_options:
         raise Exception('method options are {}'.format(method_options))
@@ -74,13 +70,16 @@ def calculate(array, pixel, masks = None, method = 'sum', convert = None,
             factor = 0.03937
 
         # m to inches
-        if convert == 'snow_depth':
+        elif convert == 'snow_depth':
             factor = 39.37
 
         # mm/pixel to TAF
-        if convert == 'volume':
+        elif convert == 'volume':
             factor = (pixel**2)*0.000000810713194*0.001
 
+        else:
+            factor = 1
+
     if units == 'SI':
 
         # mm to cm
@@ -88,13 +87,15 @@ def calculate(array, pixel, masks = None, method = 'sum', convert = None,
             factor = 0.1
 
         # m to cm
-        if convert == 'snow_depth':
+        elif convert == 'snow_depth':
             factor = 100
 
         # mm/pixel to MM^3
-        if convert == 'volume':
+        elif convert == 'volume':
             factor = (pixel**2)*0.000000810713194*1233.48/1e9
-             # ((self.pixel**2)*0.000000810713194*0.001)
+
+        else:
+            factor = 1
 
     if convert is None:
         factor = 1
@@ -285,66 +286,50 @@ def masks(dempath, convert, plotorder = None, plotlabels = None):
 
     return out
 
-def precip(rundirs_dict, path):
-    '''
-    Get daily total precip and percent rain from hourly smrf outputs in
-    expected awsm_daily format.
-
-    Needs testing for non-daily format!
+def sum_precip(precip_path, percent_snow_path):
+    """ Sum in place for precip and rain images.
 
     Args
-    -----
-    rundirs_dict : strt
-    path : str
+    ------
+    precip_path: path to precip.nc
+    percent_snow_path: path to percent_snow.nc
+    precip_total: array of total precip for the run
+    rain_total: array of total rain for the run
 
     Returns
-    -------
-    flag : bool
-    path : str
-    rain : array
-    precip : array
+    ------
+    precip: array, daily total precip
+    rain: array, daily total rain
+    """
 
-    '''
-    flag = True
-
-    sf = rundirs_dict.replace('runs','data')
-    sf = sf.replace('run','data')
-    ppt_path = sf + path
-    percent_snow_path = ppt_path.replace('precip','percent_snow')
-
-    if os.path.isfile(ppt_path):
-        ppt = nc.Dataset(ppt_path, 'r')
-        percent_snow = nc.Dataset(percent_snow_path, 'r')
-
-        # For the wy2019 daily runs, precip.nc always has an extra hour, but
-        # in some WRF forecast runs there are fewer than 24...
-        if len(ppt.variables['precip'][:]) > 24:
-            nb = 24
-
-        else:
-            nb = len(ppt.variables['precip'][:])
-
-        for nb in range(0,nb):
-            pre = ppt['precip'][nb]
-            ps = percent_snow['percent_snow'][nb]
-
-            if nb == 0:
-                rain = np.multiply(pre,(1-ps))
-                precip = copy.deepcopy(pre)
-
-            else:
-                rain = rain + np.multiply(pre,(1-ps))
-                precip = precip + copy.deepcopy(pre)
-
-        ppt.close()
-        percent_snow.close()
+    ppt = nc.Dataset(precip_path, 'r')
+    percent_snow = nc.Dataset(percent_snow_path, 'r')
 
+    # For the wy2019 daily runs, precip.nc always has an extra hour, but
+    # in some WRF forecast runs there are fewer than 24...
+    if len(ppt.variables['precip'][:]) > 24:
+        nb = 24
     else:
-        flag = False
-        rain = None
-        precip = None
+        nb = len(ppt.variables['precip'][:])
 
-    return flag, ppt_path, precip, rain
+    for nb in range(0,nb):
+        pre = ppt['precip'][nb]
+        ps = percent_snow['percent_snow'][nb]
+
+        if nb == 0:
+            rain = np.multiply(pre,(1-ps))
+            precip = copy.deepcopy(pre)
+        else:
+            rain = rain + np.multiply(pre,(1-ps))
+            precip = precip + copy.deepcopy(pre)
+
+    # rain_total = rain_total + rain
+    # precip_total = precip_total + precip
+
+    ppt.close()
+    percent_snow.close()
+
+    return precip, rain
 
 
 def input_summary(path, variable, methods, percentiles, database, location,
